#include <libint2.h>
#include <GenericContract.h>
#include <OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pg__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pg__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>

#ifdef __cplusplus
extern "C" {
#endif
void _aB_P__0__K__1___TwoPRep_S__0__K__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {

LIBINT2_REALTYPE*const  stack = parent_stack;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1788)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1791)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1800)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1803)*1+lsi)*1]), &(stack[((hsi*3+1800)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1809)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1812)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]), &(stack[((hsi*3+1809)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1818)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*6+1812)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*6+1803)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*3+1800)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1838)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*10+1818)*1+lsi)*1]), &(stack[((hsi*6+1803)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1791)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1853)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(stack[((hsi*3+1800)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1859)*1+lsi)*1]), &(stack[((hsi*6+1853)*1+lsi)*1]), &(stack[((hsi*6+1803)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(stack[((hsi*3+1800)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1869)*1+lsi)*1]), &(stack[((hsi*10+1859)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*6+1853)*1+lsi)*1]), &(stack[((hsi*6+1803)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1800)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1803)*1+lsi)*1]), &(stack[((hsi*3+1809)*1+lsi)*1]), &(stack[((hsi*3+1800)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1884)*1+lsi)*1]), &(stack[((hsi*6+1812)*1+lsi)*1]), &(stack[((hsi*6+1803)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]), &(stack[((hsi*3+1809)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1894)*1+lsi)*1]), &(stack[((hsi*10+1818)*1+lsi)*1]), &(stack[((hsi*10+1884)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*6+1812)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1909)*1+lsi)*1]), &(stack[((hsi*15+1838)*1+lsi)*1]), &(stack[((hsi*15+1894)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*10+1818)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1930)*1+lsi)*1]), &(stack[((hsi*15+1869)*1+lsi)*1]), &(stack[((hsi*15+1838)*1+lsi)*1]), &(stack[((hsi*10+1859)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1951)*1+lsi)*1]), &(stack[((hsi*21+1930)*1+lsi)*1]), &(stack[((hsi*21+1909)*1+lsi)*1]), &(stack[((hsi*15+1869)*1+lsi)*1]), &(stack[((hsi*15+1838)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1788)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*3+1800)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*6+1803)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*3+1809)*1+lsi)*1]), &(stack[((hsi*3+1800)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1979)*1+lsi)*1]), &(stack[((hsi*10+1884)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*6+1812)*1+lsi)*1]), &(stack[((hsi*6+1803)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1994)*1+lsi)*1]), &(stack[((hsi*15+1894)*1+lsi)*1]), &(stack[((hsi*15+1979)*1+lsi)*1]), &(stack[((hsi*10+1818)*1+lsi)*1]), &(stack[((hsi*10+1884)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+2015)*1+lsi)*1]), &(stack[((hsi*21+1909)*1+lsi)*1]), &(stack[((hsi*21+1994)*1+lsi)*1]), &(stack[((hsi*15+1838)*1+lsi)*1]), &(stack[((hsi*15+1894)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2043)*1+lsi)*1]), &(stack[((hsi*28+1951)*1+lsi)*1]), &(stack[((hsi*28+2015)*1+lsi)*1]), &(stack[((hsi*21+1930)*1+lsi)*1]), &(stack[((hsi*21+1909)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1809)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1812)*1+lsi)*1]), &(stack[((hsi*3+1809)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1818)*1+lsi)*1]), &(stack[((hsi*6+1812)*1+lsi)*1]), &(stack[((hsi*6+1853)*1+lsi)*1]), &(stack[((hsi*3+1809)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1838)*1+lsi)*1]), &(stack[((hsi*10+1818)*1+lsi)*1]), &(stack[((hsi*10+1859)*1+lsi)*1]), &(stack[((hsi*6+1812)*1+lsi)*1]), &(stack[((hsi*6+1853)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+2079)*1+lsi)*1]), &(stack[((hsi*15+1838)*1+lsi)*1]), &(stack[((hsi*15+1869)*1+lsi)*1]), &(stack[((hsi*10+1818)*1+lsi)*1]), &(stack[((hsi*10+1859)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+2100)*1+lsi)*1]), &(stack[((hsi*21+2079)*1+lsi)*1]), &(stack[((hsi*21+1930)*1+lsi)*1]), &(stack[((hsi*15+1838)*1+lsi)*1]), &(stack[((hsi*15+1869)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1838)*1+lsi)*1]), &(stack[((hsi*28+2100)*1+lsi)*1]), &(stack[((hsi*28+1951)*1+lsi)*1]), &(stack[((hsi*21+2079)*1+lsi)*1]), &(stack[((hsi*21+1930)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*108+2128)*1+lsi)*1]), &(stack[((hsi*36+1838)*1+lsi)*1]), &(stack[((hsi*36+2043)*1+lsi)*1]), &(stack[((hsi*28+1951)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*108+0)*1+lsi)*1]),&(stack[((hsi*108+2128)*1+lsi)*1]),108);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1791)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1930)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1874)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*6+1930)*1+lsi)*1]), &(stack[((hsi*3+1800)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1936)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*10+1874)*1+lsi)*1]), &(stack[((hsi*6+1803)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+2079)*1+lsi)*1]), &(stack[((hsi*15+1979)*1+lsi)*1]), &(stack[((hsi*15+1936)*1+lsi)*1]), &(stack[((hsi*10+1884)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1800)*1+lsi)*1]), &(stack[((hsi*21+1994)*1+lsi)*1]), &(stack[((hsi*21+2079)*1+lsi)*1]), &(stack[((hsi*15+1894)*1+lsi)*1]), &(stack[((hsi*15+1979)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2236)*1+lsi)*1]), &(stack[((hsi*28+2015)*1+lsi)*1]), &(stack[((hsi*28+1800)*1+lsi)*1]), &(stack[((hsi*21+1909)*1+lsi)*1]), &(stack[((hsi*21+1994)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1884)*1+lsi)*1]), &(stack[((hsi*36+2043)*1+lsi)*1]), &(stack[((hsi*36+2236)*1+lsi)*1]), &(stack[((hsi*28+1951)*1+lsi)*1]), &(stack[((hsi*28+2015)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2272)*1+lsi)*1]), &(stack[((hsi*36+1838)*1+lsi)*1]), &(stack[((hsi*36+2043)*1+lsi)*1]), &(stack[((hsi*28+2100)*1+lsi)*1]), &(stack[((hsi*28+1951)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*135+2317)*1+lsi)*1]), &(stack[((hsi*45+2272)*1+lsi)*1]), &(stack[((hsi*45+1884)*1+lsi)*1]), &(stack[((hsi*36+2043)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*135+108)*1+lsi)*1]),&(stack[((hsi*135+2317)*1+lsi)*1]),135);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1951)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+2100)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(stack[((hsi*3+1951)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1954)*1+lsi)*1]), &(stack[((hsi*6+1930)*1+lsi)*1]), &(stack[((hsi*6+2100)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1964)*1+lsi)*1]), &(stack[((hsi*10+1874)*1+lsi)*1]), &(stack[((hsi*10+1954)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*6+1930)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+2106)*1+lsi)*1]), &(stack[((hsi*15+1936)*1+lsi)*1]), &(stack[((hsi*15+1964)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*10+1874)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+2452)*1+lsi)*1]), &(stack[((hsi*21+2079)*1+lsi)*1]), &(stack[((hsi*21+2106)*1+lsi)*1]), &(stack[((hsi*15+1979)*1+lsi)*1]), &(stack[((hsi*15+1936)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2480)*1+lsi)*1]), &(stack[((hsi*28+1800)*1+lsi)*1]), &(stack[((hsi*28+2452)*1+lsi)*1]), &(stack[((hsi*21+1994)*1+lsi)*1]), &(stack[((hsi*21+2079)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2516)*1+lsi)*1]), &(stack[((hsi*36+2236)*1+lsi)*1]), &(stack[((hsi*36+2480)*1+lsi)*1]), &(stack[((hsi*28+2015)*1+lsi)*1]), &(stack[((hsi*28+1800)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1979)*1+lsi)*1]), &(stack[((hsi*45+1884)*1+lsi)*1]), &(stack[((hsi*45+2516)*1+lsi)*1]), &(stack[((hsi*36+2043)*1+lsi)*1]), &(stack[((hsi*36+2236)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2561)*1+lsi)*1]), &(stack[((hsi*45+2272)*1+lsi)*1]), &(stack[((hsi*45+1884)*1+lsi)*1]), &(stack[((hsi*36+1838)*1+lsi)*1]), &(stack[((hsi*36+2043)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*165+2616)*1+lsi)*1]), &(stack[((hsi*55+2561)*1+lsi)*1]), &(stack[((hsi*55+1979)*1+lsi)*1]), &(stack[((hsi*45+1884)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*165+243)*1+lsi)*1]),&(stack[((hsi*165+2616)*1+lsi)*1]),165);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1788)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*3+1951)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*6+2100)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(stack[((hsi*3+1951)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+2034)*1+lsi)*1]), &(stack[((hsi*10+1954)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*6+1930)*1+lsi)*1]), &(stack[((hsi*6+2100)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1838)*1+lsi)*1]), &(stack[((hsi*15+1964)*1+lsi)*1]), &(stack[((hsi*15+2034)*1+lsi)*1]), &(stack[((hsi*10+1874)*1+lsi)*1]), &(stack[((hsi*10+1954)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+2049)*1+lsi)*1]), &(stack[((hsi*21+2106)*1+lsi)*1]), &(stack[((hsi*21+1838)*1+lsi)*1]), &(stack[((hsi*15+1936)*1+lsi)*1]), &(stack[((hsi*15+1964)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2781)*1+lsi)*1]), &(stack[((hsi*28+2452)*1+lsi)*1]), &(stack[((hsi*28+2049)*1+lsi)*1]), &(stack[((hsi*21+2079)*1+lsi)*1]), &(stack[((hsi*21+2106)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2817)*1+lsi)*1]), &(stack[((hsi*36+2480)*1+lsi)*1]), &(stack[((hsi*36+2781)*1+lsi)*1]), &(stack[((hsi*28+1800)*1+lsi)*1]), &(stack[((hsi*28+2452)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2862)*1+lsi)*1]), &(stack[((hsi*45+2516)*1+lsi)*1]), &(stack[((hsi*45+2817)*1+lsi)*1]), &(stack[((hsi*36+2236)*1+lsi)*1]), &(stack[((hsi*36+2480)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2917)*1+lsi)*1]), &(stack[((hsi*55+1979)*1+lsi)*1]), &(stack[((hsi*55+2862)*1+lsi)*1]), &(stack[((hsi*45+1884)*1+lsi)*1]), &(stack[((hsi*45+2516)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2983)*1+lsi)*1]), &(stack[((hsi*55+2561)*1+lsi)*1]), &(stack[((hsi*55+1979)*1+lsi)*1]), &(stack[((hsi*45+2272)*1+lsi)*1]), &(stack[((hsi*45+1884)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*198+3049)*1+lsi)*1]), &(stack[((hsi*66+2983)*1+lsi)*1]), &(stack[((hsi*66+2917)*1+lsi)*1]), &(stack[((hsi*55+1979)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*198+408)*1+lsi)*1]),&(stack[((hsi*198+3049)*1+lsi)*1]),198);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1791)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1859)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1865)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*6+1859)*1+lsi)*1]), &(stack[((hsi*3+1951)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+2236)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*10+1865)*1+lsi)*1]), &(stack[((hsi*6+2100)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1875)*1+lsi)*1]), &(stack[((hsi*15+2034)*1+lsi)*1]), &(stack[((hsi*15+2236)*1+lsi)*1]), &(stack[((hsi*10+1954)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1800)*1+lsi)*1]), &(stack[((hsi*21+1838)*1+lsi)*1]), &(stack[((hsi*21+1875)*1+lsi)*1]), &(stack[((hsi*15+1964)*1+lsi)*1]), &(stack[((hsi*15+2034)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1896)*1+lsi)*1]), &(stack[((hsi*28+2049)*1+lsi)*1]), &(stack[((hsi*28+1800)*1+lsi)*1]), &(stack[((hsi*21+2106)*1+lsi)*1]), &(stack[((hsi*21+1838)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2251)*1+lsi)*1]), &(stack[((hsi*36+2781)*1+lsi)*1]), &(stack[((hsi*36+1896)*1+lsi)*1]), &(stack[((hsi*28+2452)*1+lsi)*1]), &(stack[((hsi*28+2049)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+3247)*1+lsi)*1]), &(stack[((hsi*45+2817)*1+lsi)*1]), &(stack[((hsi*45+2251)*1+lsi)*1]), &(stack[((hsi*36+2480)*1+lsi)*1]), &(stack[((hsi*36+2781)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+3302)*1+lsi)*1]), &(stack[((hsi*55+2862)*1+lsi)*1]), &(stack[((hsi*55+3247)*1+lsi)*1]), &(stack[((hsi*45+2516)*1+lsi)*1]), &(stack[((hsi*45+2817)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+2452)*1+lsi)*1]), &(stack[((hsi*66+2917)*1+lsi)*1]), &(stack[((hsi*66+3302)*1+lsi)*1]), &(stack[((hsi*55+1979)*1+lsi)*1]), &(stack[((hsi*55+2862)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+3368)*1+lsi)*1]), &(stack[((hsi*66+2983)*1+lsi)*1]), &(stack[((hsi*66+2917)*1+lsi)*1]), &(stack[((hsi*55+2561)*1+lsi)*1]), &(stack[((hsi*55+1979)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*234+3446)*1+lsi)*1]), &(stack[((hsi*78+3368)*1+lsi)*1]), &(stack[((hsi*78+2452)*1+lsi)*1]), &(stack[((hsi*66+2917)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*234+606)*1+lsi)*1]),&(stack[((hsi*234+3446)*1+lsi)*1]),234);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1932)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_13[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1935)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(stack[((hsi*3+1932)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1941)*1+lsi)*1]), &(stack[((hsi*6+1859)*1+lsi)*1]), &(stack[((hsi*6+1935)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+2530)*1+lsi)*1]), &(stack[((hsi*10+1865)*1+lsi)*1]), &(stack[((hsi*10+1941)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*6+1859)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+2296)*1+lsi)*1]), &(stack[((hsi*15+2236)*1+lsi)*1]), &(stack[((hsi*15+2530)*1+lsi)*1]), &(stack[((hsi*10+1828)*1+lsi)*1]), &(stack[((hsi*10+1865)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1951)*1+lsi)*1]), &(stack[((hsi*21+1875)*1+lsi)*1]), &(stack[((hsi*21+2296)*1+lsi)*1]), &(stack[((hsi*15+2034)*1+lsi)*1]), &(stack[((hsi*15+2236)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2545)*1+lsi)*1]), &(stack[((hsi*28+1800)*1+lsi)*1]), &(stack[((hsi*28+1951)*1+lsi)*1]), &(stack[((hsi*21+1838)*1+lsi)*1]), &(stack[((hsi*21+1875)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1979)*1+lsi)*1]), &(stack[((hsi*36+1896)*1+lsi)*1]), &(stack[((hsi*36+2545)*1+lsi)*1]), &(stack[((hsi*28+2049)*1+lsi)*1]), &(stack[((hsi*28+1800)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2024)*1+lsi)*1]), &(stack[((hsi*45+2251)*1+lsi)*1]), &(stack[((hsi*45+1979)*1+lsi)*1]), &(stack[((hsi*36+2781)*1+lsi)*1]), &(stack[((hsi*36+1896)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+3680)*1+lsi)*1]), &(stack[((hsi*55+3247)*1+lsi)*1]), &(stack[((hsi*55+2024)*1+lsi)*1]), &(stack[((hsi*45+2817)*1+lsi)*1]), &(stack[((hsi*45+2251)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+2781)*1+lsi)*1]), &(stack[((hsi*66+3302)*1+lsi)*1]), &(stack[((hsi*66+3680)*1+lsi)*1]), &(stack[((hsi*55+2862)*1+lsi)*1]), &(stack[((hsi*55+3247)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*91+3746)*1+lsi)*1]), &(stack[((hsi*78+2452)*1+lsi)*1]), &(stack[((hsi*78+2781)*1+lsi)*1]), &(stack[((hsi*66+2917)*1+lsi)*1]), &(stack[((hsi*66+3302)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*91+3837)*1+lsi)*1]), &(stack[((hsi*78+3368)*1+lsi)*1]), &(stack[((hsi*78+2452)*1+lsi)*1]), &(stack[((hsi*66+2983)*1+lsi)*1]), &(stack[((hsi*66+2917)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*273+3928)*1+lsi)*1]), &(stack[((hsi*91+3837)*1+lsi)*1]), &(stack[((hsi*91+3746)*1+lsi)*1]), &(stack[((hsi*78+2452)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*273+840)*1+lsi)*1]),&(stack[((hsi*273+3928)*1+lsi)*1]),273);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1788)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_13[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_14[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*3+1932)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_13[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+2859)*1+lsi)*1]), &(stack[((hsi*6+1935)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(stack[((hsi*3+1932)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+2869)*1+lsi)*1]), &(stack[((hsi*10+1941)*1+lsi)*1]), &(stack[((hsi*10+2859)*1+lsi)*1]), &(stack[((hsi*6+1859)*1+lsi)*1]), &(stack[((hsi*6+1935)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+2884)*1+lsi)*1]), &(stack[((hsi*15+2530)*1+lsi)*1]), &(stack[((hsi*15+2869)*1+lsi)*1]), &(stack[((hsi*10+1865)*1+lsi)*1]), &(stack[((hsi*10+1941)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+2905)*1+lsi)*1]), &(stack[((hsi*21+2296)*1+lsi)*1]), &(stack[((hsi*21+2884)*1+lsi)*1]), &(stack[((hsi*15+2236)*1+lsi)*1]), &(stack[((hsi*15+2530)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2933)*1+lsi)*1]), &(stack[((hsi*28+1951)*1+lsi)*1]), &(stack[((hsi*28+2905)*1+lsi)*1]), &(stack[((hsi*21+1875)*1+lsi)*1]), &(stack[((hsi*21+2296)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2969)*1+lsi)*1]), &(stack[((hsi*36+2545)*1+lsi)*1]), &(stack[((hsi*36+2933)*1+lsi)*1]), &(stack[((hsi*28+1800)*1+lsi)*1]), &(stack[((hsi*28+1951)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1800)*1+lsi)*1]), &(stack[((hsi*45+1979)*1+lsi)*1]), &(stack[((hsi*45+2969)*1+lsi)*1]), &(stack[((hsi*36+1896)*1+lsi)*1]), &(stack[((hsi*36+2545)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+1855)*1+lsi)*1]), &(stack[((hsi*55+2024)*1+lsi)*1]), &(stack[((hsi*55+1800)*1+lsi)*1]), &(stack[((hsi*45+2251)*1+lsi)*1]), &(stack[((hsi*45+1979)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+4201)*1+lsi)*1]), &(stack[((hsi*66+3680)*1+lsi)*1]), &(stack[((hsi*66+1855)*1+lsi)*1]), &(stack[((hsi*55+3247)*1+lsi)*1]), &(stack[((hsi*55+2024)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*91+4279)*1+lsi)*1]), &(stack[((hsi*78+2781)*1+lsi)*1]), &(stack[((hsi*78+4201)*1+lsi)*1]), &(stack[((hsi*66+3302)*1+lsi)*1]), &(stack[((hsi*66+3680)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*105+3247)*1+lsi)*1]), &(stack[((hsi*91+3746)*1+lsi)*1]), &(stack[((hsi*91+4279)*1+lsi)*1]), &(stack[((hsi*78+2452)*1+lsi)*1]), &(stack[((hsi*78+2781)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*105+4370)*1+lsi)*1]), &(stack[((hsi*91+3837)*1+lsi)*1]), &(stack[((hsi*91+3746)*1+lsi)*1]), &(stack[((hsi*78+3368)*1+lsi)*1]), &(stack[((hsi*78+2452)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*315+4475)*1+lsi)*1]), &(stack[((hsi*105+4370)*1+lsi)*1]), &(stack[((hsi*105+3247)*1+lsi)*1]), &(stack[((hsi*91+3746)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*315+1113)*1+lsi)*1]),&(stack[((hsi*315+4475)*1+lsi)*1]),315);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1791)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_14[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_15[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+3352)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]), &(stack[((hsi*3+1791)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_13[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_14[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+3358)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]), &(stack[((hsi*6+3352)*1+lsi)*1]), &(stack[((hsi*3+1932)*1+lsi)*1]), &(stack[((hsi*3+1788)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+2452)*1+lsi)*1]), &(stack[((hsi*10+2859)*1+lsi)*1]), &(stack[((hsi*10+3358)*1+lsi)*1]), &(stack[((hsi*6+1935)*1+lsi)*1]), &(stack[((hsi*6+1794)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+3352)*1+lsi)*1]), &(stack[((hsi*15+2869)*1+lsi)*1]), &(stack[((hsi*15+2452)*1+lsi)*1]), &(stack[((hsi*10+1941)*1+lsi)*1]), &(stack[((hsi*10+2859)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+2452)*1+lsi)*1]), &(stack[((hsi*21+2884)*1+lsi)*1]), &(stack[((hsi*21+3352)*1+lsi)*1]), &(stack[((hsi*15+2530)*1+lsi)*1]), &(stack[((hsi*15+2869)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+3352)*1+lsi)*1]), &(stack[((hsi*28+2905)*1+lsi)*1]), &(stack[((hsi*28+2452)*1+lsi)*1]), &(stack[((hsi*21+2296)*1+lsi)*1]), &(stack[((hsi*21+2884)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2452)*1+lsi)*1]), &(stack[((hsi*36+2933)*1+lsi)*1]), &(stack[((hsi*36+3352)*1+lsi)*1]), &(stack[((hsi*28+1951)*1+lsi)*1]), &(stack[((hsi*28+2905)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+3352)*1+lsi)*1]), &(stack[((hsi*45+2969)*1+lsi)*1]), &(stack[((hsi*45+2452)*1+lsi)*1]), &(stack[((hsi*36+2545)*1+lsi)*1]), &(stack[((hsi*36+2933)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2452)*1+lsi)*1]), &(stack[((hsi*55+1800)*1+lsi)*1]), &(stack[((hsi*55+3352)*1+lsi)*1]), &(stack[((hsi*45+1979)*1+lsi)*1]), &(stack[((hsi*45+2969)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+2859)*1+lsi)*1]), &(stack[((hsi*66+1855)*1+lsi)*1]), &(stack[((hsi*66+2452)*1+lsi)*1]), &(stack[((hsi*55+2024)*1+lsi)*1]), &(stack[((hsi*55+1800)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*91+1921)*1+lsi)*1]), &(stack[((hsi*78+4201)*1+lsi)*1]), &(stack[((hsi*78+2859)*1+lsi)*1]), &(stack[((hsi*66+3680)*1+lsi)*1]), &(stack[((hsi*66+1855)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*105+2859)*1+lsi)*1]), &(stack[((hsi*91+4279)*1+lsi)*1]), &(stack[((hsi*91+1921)*1+lsi)*1]), &(stack[((hsi*78+2781)*1+lsi)*1]), &(stack[((hsi*78+4201)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pg__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*120+1788)*1+lsi)*1]), &(stack[((hsi*105+3247)*1+lsi)*1]), &(stack[((hsi*105+2859)*1+lsi)*1]), &(stack[((hsi*91+3746)*1+lsi)*1]), &(stack[((hsi*91+4279)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pg__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*120+2781)*1+lsi)*1]), &(stack[((hsi*105+4370)*1+lsi)*1]), &(stack[((hsi*105+3247)*1+lsi)*1]), &(stack[((hsi*91+3837)*1+lsi)*1]), &(stack[((hsi*91+3746)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pg__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*360+4790)*1+lsi)*1]), &(stack[((hsi*120+2781)*1+lsi)*1]), &(stack[((hsi*120+1788)*1+lsi)*1]), &(stack[((hsi*105+3247)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*360+1428)*1+lsi)*1]),&(stack[((hsi*360+4790)*1+lsi)*1]),360);
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 1788 */
}

#ifdef __cplusplus
};
#endif
